function [T,Tq,x,y] = Ytime(q, oASD, n, nloci, SMM, Rgrowth, mua, mub, anc, MCruns)
%function [T,Tq] = Ytime(q, oASD, n, nloci, SMM, Rgrowth, mua, mub, anc, Tqlow, Tqup, bins, MCruns)
%T is the unbiased estimate of the TMRCA, in generations
%Tq is the series of confidence limit estimates provided for the quantiles specified in q
%
%The input parameters (inside curved brackets) are as follows:
%q = vector of quantiles for which tq required.  e.g, set q=[0.025 0.975] for equal-tailed 95% confidence limits.  Set q=[] for no Tq.
%oASD = observed Average Square Distance between each sampled chromosome and the MRCA STR-haplotype.
%n = number of sampled chromosomes.
%nloci = number of STR loci typed for each chromosome.
%SMM = 'S-SMM' selects Simple Stepwise Mutation Model. SMM='L-SMM' selects the Linear Length Dependent Stepwise Mutation Model.
%Rgrowth = scaled rate parameter R for the growth model (R=N*r). Rgrowth=0 sets no-growth model. Rgrowth='star' sets a star-genealogy model.
%mua = mutation rate (per gen) under S-SMM, = intercept under L_SMM. Specify single value or 'nloci' values.
%mub = intercept under L_SMM. Specify single value or 'nloci' values. Do not need to specifiy under S-SMM.
%anc = row vector giving MRCA haplotype under L-SSM, not used under S-SMM.
%
%MCruns specifies the number of simulations to perform at each value of T (default=1000).

if nargin<10
  MCruns=1000;		%sets number of runs under which to simulate each set of ASD values
end

if any(q<=0)|any(q>=1)
    disp('WARNING! WARNING! WARNING!')
    disp('some values in vector q are outside legal range 0<q<1')
    q
end

if SMM=='S-SMM'
  mu = mua;				    %under S-SMM, mu (mutation rates at each locus) stored in "mua"
  mub = zeros(1,nloci);				%give dummy value for "mub"
  anc = zeros(1,nloci);		%give dummy value for "anc"
elseif SMM=='L-SMM'
  %under LLD-SMM, mu for each locus is given by mu estimated for MRCA haplotype
  mu = mua + mub.*anc;
  mu = mu - (mu<0).*mu;
else
  disp('Fatal Error: SMM text string not S-SMM or L-SMM')
  return
end

%convert mua and mub to vectors, if need be
if length(mua)==1
  mua = ones(1,nloci)*mua;
end
if length(mub)==1
  mub = ones(1,nloci)*mub;
end

%use mu to come up with T
T = oASD/mean(mu);


if length(q)==0
  %no quantiles asked for - stop here
  tq=[];
else
  disp(['Starting simulations, MC runs per iteration = ' num2str(MCruns) ' ...'])
  %Start by simulating a range of possible ASD values under the "naive" estimate of T
  simASD0 = simASD(MCruns, T, n, nloci, SMM, Rgrowth, mua, mub, anc);
  %now find tq for each value of q
  for i=1:length(q)
    disp(['Finding quantile ' num2str(q(i)) ' ...'])
    %Find first guess at where quantile is, based on simASD0
    %Basic idea is that ratio of T to tq[1-q] is guide to ratio of tq[q] to T
    if quantile(simASD0,1-q(i))>0
      tq_new = T * mean(simASD0)/quantile(simASD0,1-q(i));
    else                                                    %can't use ratio, cos quantile=0
      if quantile(simASD0,q(i))>0
        tq_new = T * quantile(simASD0,q(i))/mean(simASD0);	  %our best guess is to use quantile on other side
      else                                                  %can't use quantile on other side either - occurs if T=0
        tq_new = 1000;                                        %this is just some arbitrary non-zero number
      end
    end
    %Keep looking for tq until returned value within range
    keepon=1;
    while keepon>0
      disp(['  Current estimate = ' num2str(tq_new) ' ...'])
      tq(i) = findt(q(i), oASD, n, nloci, SMM, Rgrowth, mua, mub, anc, tq_new/2, tq_new*1.5, 9, MCruns);
%      [x y]  %to see these, use [tq(i),x,y] = findt(...)
      if (tq(i)>tq_new/2)&(tq(i)<tq_new*1.5)
        keepon=0;
      else
        if tq(i)>0
          tq_new = tq(i);
        else
          %since Tq<0, use half distance to zero instead, or abs Tq
          tq_new = min([abs(tq(i)) tq_new/2]);
        end
      end
    end   %of 'while' loop
    disp(['  Final estimate = ' num2str(tq(i))])
  end
end

Tq=tq;