function [tq,x,y] = findt(q, oASD, n, nloci, SMM, Rgrowth, mua, mub, anc, Tqlow, Tqup, bins, MCruns)
%function [tq,x,y] = findt(q, oASD, n, nloci, SMM, Rgrowth, mua, mub, anc, Tqlow, Tqup, bins, MCruns)
%The input parameters (inside curved brackets) are as follows:
%q = vector of quantiles for which tq required.  e.g, set q=[0.025 0.975] for equal-tailed 95% confidence limits.  Set q=[] for no Tq.
%oASD = observed Average Square Distance between each sampled chromosome and the MRCA STR-haplotype.
%n = number of sampled chromosomes.
%nloci = number of STR loci typed for each chromosome.
%SMM = 'S-SMM' selects Simple Stepwise Mutation Model. SMM='L-SMM' selects the Linear Length Dependent Stepwise Mutation Model.
%Rgrowth = scaled rate parameter R for the growth model (R=N*r). Rgrowth=0 sets no-growth model. Rgrowth='star' sets a star-genealogy model.
%mua = mutation rate (per gen) under S-SMM, = intercept under LLD_SMM. Specify single value or 'nloci' values.
%mub = intercept under LLD_SMM. Specify single value or 'nloci' values. Do not need to specifiy under LLD-SMM.
%anc = row vector giving MRCA haplotype under LLD-SSM, not used under S-SMM.
%
%The following additional parameters are available:
%Tqlow specifies the lower value of Tq to be simulated in range-finding.
%Tqup specifies the upper value of Tq to be simulated.
%bins specifies the number of Tq values to be simulated (evenly spaced between Tqlow and Tqup).
%MCruns specifies the number of simulations to perform at each value of T (default=1000).

if nargin<13
  MCruns=1000;
end

range = Tqup-Tqlow;
tq_new = Tqlow+range/2;

  units = (0:(bins-1))';
  if bins>1, units=units./(bins-1); end
  x = Tqlow + range.*units;		%note we already have the y-point for central x-point
  y = zeros(bins,1);					%will contain (1-q)-ASD values
  for i=1:bins
    ASD = simASD(MCruns, x(i), n, nloci, SMM, Rgrowth, mua, mub, anc);
    y(i) = quantile(ASD,1-q);
  end

  if sum(y==0)<(bins-2)
    %do quadratic regression, using b=X\y
    b = [ones(9,1) x x.^2]\y;
    %solve x for y=oASD
    root = quadroot(b(3),b(2),b(1)-oASD);
    %find root that is closest to tq_new
    root_diff = abs(root-tq_new);
    best_root = root(root_diff==min(root_diff));
  else
    %Too many zero values.  Use last value of x(i) as your best guess
    best_root = x(bins);
  end
    
tq = best_root;
