function M = growth(n,R)
%function M = growth(n,R)
%Simulates coalescent w/ growth (in units of Nc gens, where Nc=current), for n sampled at tip
%R = Nc.r, where r= growth rate per generation
%WARNING! This function will fail if called with R=0!
%Simulates coalescent tree as M where:
%First n rows = terminal nodes
%Next (n-1) rows = internal nodes.
%First col = time (going backwards) in units of (N=total pop size), since start
%2nd col =  index of father
%3rd col = index of right descendent
%4th col = index of left descendent

%To understand algorithm, see Donnelly and Tavare (1995) "Coalescents and genealogical structure under neutrality", Annu. Rev. Genet. 29: 401-421, p.406
%Using their notation, lambda(t)= exp(Rt) and capitallambda(t)= (exp(Rt)-1)/R, where R=Nc.r and t is measured in units of Nc gens
%They show that P(t(j)>t|s) = exp(-B(j)*(capitallambda(t+s) - capitallambda(s))
%Solving for their Eq(5) yields t(j) = log( 1 - R*log(U)/B(j)/exp(Rs) )/R
%where t(j) is the time to next coalescent event, B(j)=no. of possible pairwise combinations between the current existing lineages, and s is current time since present day
%and U is a r.v. taken from U(0,1)

M = zeros(2*n-1,4);

X=(1:n); nX=n;    		%stores list of indices for currently "active" lines

for i=n+1:2*n-1		%build up each coalescent event until TMRCA
  M(i,1) = M(i-1,1) + log( 1 - R*log(rand)*2/nX/(nX-1)/exp(R*M(i-1,1)) )/R;
  %choose descendents
  d1 = X(ceil(rand*nX));  X = X(X~=d1);
  nX=nX-1;
  d2 = X(ceil(rand*nX));
  X(X==d2) = i;		%i.e. get rid of d1 from X, put "i" instead of d2 into X
  M(i,3)=d1;   M(i,4)=d2;
  M(d1,2)=i;  M(d2,2)=i;
end

